camelot.camelot.empty_project.settings

Package camelot :: Package camelot :: Package empty_project :: Module settings |
[hide private]
[frames] | no frames]

# Module settings

source code

Functions | [hide private]
setup_model() | source code
ENGINE() sqlite:///model-data.sqlite | source code

Variables | [hide private]
| CAMELOT_MAIN_DIRECTORY = ``'``/home/tw55413/sandbox/camelot``'``
| CAMELOT_ART_DIRECTORY = ``'``/home/tw55413/sandbox/camelot/art``'``
| CAMELOT_TEMPLATES_DIRECTORY = ``'``/home/tw55413/sandbox/camelot/v``...``
| CAMELOT_ATTACHMENTS = ``'````'``
| CAMELOT_MEDIA_ROOT = ``'````'``

Variables Details | [hide private]

  ### CAMELOT_TEMPLATES_DIRECTORY Value:
      '/home/tw55413/sandbox/camelot/view/templates'